/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package cz.cvut.kbss.ejaservlets.support;

/**
 * Caesarova sifra
 * @author Pavel Micka
 */
public class CaesarCipher {
    /**
     * Posun (Caesarova sifra ma 3)
     */
    public static final int DEFAULT_SHIFT = 3;
    
    private static int shift = DEFAULT_SHIFT;
    
    /**
     * Nastavi posun pro Caesarovu sifru.
     * @param newShift Novy posun
     * @throws IllegalArgumentException Kdyz je novy posun roven 0
     */
    public static void setShift(int newShift) {
        if (newShift == 0) {
            throw new IllegalArgumentException("Shift nemuze byt 0, sifra by nebyla moc bezpecna.");
        }
        shift = newShift;
    }

    /**
     * Zasifruje Caesarovou sifrou
     * @param s retezec obsahujici pouze velka pismena
     * @return zasifrovany retezec
     */
    public static String encipher(String s){
        StringBuilder builder = new StringBuilder();
        for(int i = 0; i < s.length(); i ++){
            if(s.charAt(i) < 65 || s.charAt(i) > 90){ //znak v ASCII
                throw new IllegalArgumentException("" +
                        "Sifrovany retezec neobsahuje jen velka pismena");
            }
            //modularne pricteme shift
            char enciphered = s.charAt(i) + shift > 90 ? (char)((s.charAt(i) + shift) - 26) : (char)(s.charAt(i) + shift);
            builder.append(enciphered);
        }
        return builder.toString();
    }
    /**
     * Desifruje retezec zasifrovany Caesarovou sifrou
     * @param s retezec k desiforvani
     * @return desifrovany retezec
     */
    public static String decipher(String s){
        StringBuilder builder = new StringBuilder();
        for(int i = 0; i < s.length(); i ++){
            if(s.charAt(i) < 65 || s.charAt(i) > 90){ //znak v ASCII
                throw new IllegalArgumentException("" +
                        "Desifrovany retezec neobsahuje jen velka pismena");
            }
            //modularne odecteme shift
            char deciphered = s.charAt(i) - shift < 65 ? (char)((s.charAt(i) - shift) + 26) : (char)(s.charAt(i) - shift);
            builder.append(deciphered);
        }
        return builder.toString();
    }
}